## [1.6.0](https://github.com/ocni-dtu/lcax/compare/v1.5.0...v1.6.0) (2024-03-26)


### Features

* renamed fields ([e37d35b](https://github.com/ocni-dtu/lcax/commit/e37d35bd6da80b0295d2a8f2be5ac280699aaff8))

## [1.5.0](https://github.com/ocni-dtu/lcax/compare/v1.4.2...v1.5.0) (2024-03-26)


### Features

* added convert functions to JS and Python ([7d22438](https://github.com/ocni-dtu/lcax/commit/7d22438fa4793d67965ede591fa1613dda2ff535))
* added support for LCAbyg result files ([0dd026f](https://github.com/ocni-dtu/lcax/commit/0dd026f08f7a3fede61b43e138e39fde1f7381aa))
* initial implementation of parsing LCAbyg projects ([84dae7e](https://github.com/ocni-dtu/lcax/commit/84dae7e92b2c0b39c0f8fcaf0352de65cd31c16f))
* updated LCAx data structure ([f0c69f2](https://github.com/ocni-dtu/lcax/commit/f0c69f2fc59ac0bfc72385f493d5db0bc6ad5786))


### Bug Fixes

* resolved test issues ([e25287d](https://github.com/ocni-dtu/lcax/commit/e25287dd6a87c9be56af7c9b78d6ad30fea410d4))

## [1.4.2](https://github.com/ocni-dtu/lcax/compare/v1.4.1...v1.4.2) (2024-01-01)


### Bug Fixes

* updated C# types generation ([aeb9fb8](https://github.com/ocni-dtu/lcax/commit/aeb9fb886b2ebe00943b87f2489a8f3b741e44dd))

## [1.4.1](https://github.com/ocni-dtu/lcax/compare/v1.4.0...v1.4.1) (2023-12-31)


### Bug Fixes

* updated working dir cs ([63180d2](https://github.com/ocni-dtu/lcax/commit/63180d28aa60eb72bb2c3b249d0cfdf6f982f504))

## [1.4.0](https://github.com/ocni-dtu/lcax/compare/v1.3.1...v1.4.0) (2023-12-31)


### Features

* added nuget package ([803a212](https://github.com/ocni-dtu/lcax/commit/803a212eb8f86097ab2242a0a63adabf87ce91fc))

## [1.3.1](https://github.com/ocni-dtu/lcax/compare/v1.3.0...v1.3.1) (2023-08-25)


### Bug Fixes

* fixed npm build and publish ([3c1a464](https://github.com/ocni-dtu/lcax/commit/3c1a46420ea8354950b9e1d5bd3167eb0b79d743))

## [1.3.0](https://github.com/ocni-dtu/lcax/compare/v1.2.5...v1.3.0) (2023-08-25)


### Features

* creating NPM package for LCAx ([b429581](https://github.com/ocni-dtu/lcax/commit/b429581b4562708d23bfee5fbdaed1af7a962bb7))

## [1.2.5](https://github.com/ocni-dtu/lcax/compare/v1.2.4...v1.2.5) (2023-08-23)


### Bug Fixes

* added pydantic.py to release/wheel ([1909c79](https://github.com/ocni-dtu/lcax/commit/1909c79afe1e0d3a8bc9f822dfc3ead8ddd6f708))

## [1.2.4](https://github.com/ocni-dtu/lcax/compare/v1.2.3...v1.2.4) (2023-08-23)


### Bug Fixes

* updated python publish command ([4b6412d](https://github.com/ocni-dtu/lcax/commit/4b6412d6a4c8c5ab87d20929b6173e70244968fe))

## [1.2.3](https://github.com/ocni-dtu/lcax/compare/v1.2.2...v1.2.3) (2023-08-23)


### Bug Fixes

* updated python dependencies ([1ba400c](https://github.com/ocni-dtu/lcax/commit/1ba400cd7ce653c66e1e3b4dc669bde8db42fc43))

## [1.2.2](https://github.com/ocni-dtu/lcax/compare/v1.2.1...v1.2.2) (2023-08-22)


### Bug Fixes

* updated Pydantic model generation ([bb61375](https://github.com/ocni-dtu/lcax/commit/bb61375d1cb25bc6881474d4a1487b71067e24cb))

## [1.2.1](https://github.com/ocni-dtu/lcax/compare/v1.2.0...v1.2.1) (2023-08-22)


### Bug Fixes

* corrected pydantic location ([9268be1](https://github.com/ocni-dtu/lcax/commit/9268be12a5b2289cb1d81ee3a82fa275aadd50f5))

## [1.2.0](https://github.com/ocni-dtu/lcax/compare/v1.1.1...v1.2.0) (2023-08-21)


### Features

* made enums lowercase and structs camelCase ([23a81f0](https://github.com/ocni-dtu/lcax/commit/23a81f0242ba14c67fd19c1e3db3ef196a515c11))

## [1.1.1](https://github.com/ocni-dtu/lcax/compare/v1.1.0...v1.1.1) (2023-08-17)


### Bug Fixes

* added test cases and fixed issues with Python packaging ([39680eb](https://github.com/ocni-dtu/lcax/commit/39680eb98d07fa5f218d0bbbea09648d7314645b))

## [1.1.0](https://github.com/ocni-dtu/lcax/compare/v1.0.0...v1.1.0) (2023-08-16)


### Features

* updated result object ([feafef6](https://github.com/ocni-dtu/lcax/commit/feafef6e7870b02befddf9dc8aef9f062020bb8b))
* updated result object ([8e096c0](https://github.com/ocni-dtu/lcax/commit/8e096c07af19dd0bf53520481b86a5773400f7b3))
* updated transport object ([98da16b](https://github.com/ocni-dtu/lcax/commit/98da16b31f76f35cfe7b43579d29cd4e52395511))

## 1.0.0 (2023-08-16)


### Bug Fixes

* updated epdx package ([d474eac](https://github.com/ocni-dtu/lcax/commit/d474eac39d4544c5fde2f1383ddcf86d0845d894))
